[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,60 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/allocators/adapters.cuh>
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main()
|
||||
{
|
||||
double* d_ptrA;
|
||||
const size_t N = 128 * 1024;
|
||||
const size_t NITER = 10;
|
||||
|
||||
// User allocated memory
|
||||
cuda_safe_call(cudaMalloc(&d_ptrA, N * sizeof(double)));
|
||||
|
||||
async_resources_handle handle;
|
||||
|
||||
cudaStream_t stream;
|
||||
cuda_safe_call(cudaStreamCreate(&stream));
|
||||
|
||||
for (size_t i = 0; i < NITER; i++)
|
||||
{
|
||||
graph_ctx ctx(stream, handle);
|
||||
|
||||
// The uncached allocator of the context will be using cudaMallocAsync(...,
|
||||
// stream) to avoid creating memory nodes in the graph (because they are
|
||||
// costly and caching the graph also keeps memory allocated)
|
||||
auto wrapper = stream_adapter(ctx, stream);
|
||||
|
||||
ctx.set_allocator(block_allocator<buddy_allocator>(ctx, wrapper.allocator()));
|
||||
|
||||
auto A = ctx.logical_data(make_slice(d_ptrA, N), data_place::current_device());
|
||||
|
||||
for (size_t k = 0; k < 4; k++)
|
||||
{
|
||||
auto tmp = ctx.logical_data(A.shape());
|
||||
auto tmp2 = ctx.logical_data(A.shape());
|
||||
// Test device and managed memory
|
||||
ctx.parallel_for(A.shape(), A.read(), tmp.write(), tmp2.write(data_place::managed()))
|
||||
->*[] __device__(size_t i, auto a, auto tmp, auto tmp2) {
|
||||
tmp(i) = a(i);
|
||||
tmp2(i) = a(i);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
wrapper.clear();
|
||||
}
|
||||
cuda_safe_call(cudaStreamSynchronize(stream));
|
||||
}
|
||||
@@ -1,43 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
/**
|
||||
* @brief Ensure the buddy allocation is working properly on the different backends
|
||||
*/
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
template <typename ctx_t>
|
||||
void test_buddy()
|
||||
{
|
||||
ctx_t ctx;
|
||||
ctx.set_allocator(block_allocator<buddy_allocator>(ctx));
|
||||
|
||||
std::vector<logical_data<slice<char>>> data;
|
||||
for (size_t i = 0; i < 10; i++)
|
||||
{
|
||||
size_t s = (1 + i % 8) * 1024ULL * 1024ULL;
|
||||
auto l = ctx.logical_data(shape_of<slice<char>>(s));
|
||||
data.push_back(l);
|
||||
|
||||
ctx.task(l.write())->*[](cudaStream_t, auto) {};
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
|
||||
int main(int, char**)
|
||||
{
|
||||
test_buddy<stream_ctx>();
|
||||
test_buddy<graph_ctx>();
|
||||
test_buddy<context>();
|
||||
}
|
||||
@@ -1,56 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main(int, char**)
|
||||
{
|
||||
context ctx;
|
||||
|
||||
const size_t PART_SIZE = 1024;
|
||||
const size_t PART_CNT = 64;
|
||||
|
||||
pooled_allocator_config config;
|
||||
config.max_entries_per_place = 8;
|
||||
auto fixed_alloc = block_allocator<pooled_allocator>(ctx, config);
|
||||
|
||||
/* Create a large device buffer which will be used part by part. */
|
||||
double* dA;
|
||||
cuda_safe_call(cudaMalloc(&dA, PART_SIZE * PART_CNT * sizeof(double)));
|
||||
|
||||
for (size_t p = 0; p < PART_CNT; p++)
|
||||
{
|
||||
/* Create a logical data from a subset of the existing device buffer */
|
||||
auto Ap = ctx.logical_data(make_slice(&dA[p * PART_SIZE], PART_SIZE), data_place::current_device());
|
||||
|
||||
ctx.parallel_for(Ap.shape(), Ap.write()).set_symbol("init_Ap")->*[p, PART_SIZE] __device__(size_t i, auto ap) {
|
||||
ap(i) = 1.0 * (i + p * PART_SIZE);
|
||||
};
|
||||
|
||||
auto tmp = ctx.logical_data(Ap.shape());
|
||||
tmp.set_allocator(fixed_alloc);
|
||||
|
||||
ctx.parallel_for(Ap.shape(), Ap.read(), tmp.write()).set_symbol("set_tmp")->*
|
||||
[] __device__(size_t i, auto ap, auto tmp) {
|
||||
tmp(i) = 2.0 * ap(i);
|
||||
};
|
||||
|
||||
ctx.parallel_for(Ap.shape(), Ap.write(), tmp.read()).set_symbol("update_Ap")
|
||||
->*[] __device__(size_t i, auto ap, auto tmp) {
|
||||
ap(i) = tmp(i);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
cuda_safe_call(cudaFree(dA));
|
||||
}
|
||||
Reference in New Issue
Block a user